Type: Package
Package: admiralonco
Title: Oncology Extension Package for ADaM in 'R' Asset Library
Version: 1.5.0
Authors@R: c(
    person("Stefan", "Bundfuss", , "stefan.bundfuss@external.roche.com", role = c("aut", "cre")),
    person("Amit", "Jain", role = "aut"),
    person("Vinh", "Nguyen", role = "aut"),
    person("Olga", "Starostecka", role = "aut"),
    person("Kiran", "Peddamudium", role = "aut"),
    person("Tomoyuki", "Namai", role = "aut"),
    person("Ross", "Farrugia", role = "aut"),
    person("Yirong", "Cao", role = "ctb"),
    person("F. Hoffmann-La Roche AG", role = c("cph", "fnd")),
    person("GlaxoSmithKline LLC", role = c("cph", "fnd")),
    person("Bristol Myers Squibb", role = c("cph", "fnd"))
  )
Description: Programming oncology specific Clinical Data Interchange
    Standards Consortium (CDISC) compliant Analysis Data Model (ADaM)
    datasets in 'R'. ADaM datasets are a mandatory part of any New Drug or
    Biologics License Application submitted to the United States Food and
    Drug Administration (FDA). Analysis derivations are implemented in
    accordance with the "Analysis Data Model Implementation Guide" (CDISC
    Analysis Data Model Team (2021),
    <https://www.cdisc.org/standards/foundational/adam>).  The package is
    an extension package of the 'admiral' package.
License: Apache License (>= 2)
URL: https://pharmaverse.github.io/admiralonco/,
        https://github.com/pharmaverse/admiralonco
BugReports: https://github.com/pharmaverse/admiralonco/issues
Depends: R (>= 3.5)
Imports: admiral (>= 1.0.0), admiraldev (>= 1.0.0), cli, dplyr (>=
        0.8.4), lifecycle (>= 0.1.0), lubridate (>= 1.7.4), magrittr
        (>= 1.5), rlang (>= 0.4.4), tidyselect (>= 1.0.0)
Suggests: covr, devtools, diffdf, DT, ggplot2, gt, here, knitr, lintr,
        metatools, methods, miniUI, pharmaverseadam, pharmaversesdtm,
        pkgdown, rmarkdown, roxygen2, spelling, stringr, testthat (>=
        3.0.0), tibble, usethis, withr
VignetteBuilder: knitr
Config/roxygen2/markdown: TRUE
Config/roxygen2/version: 8.1.0
Config/testthat/edition: 3
Encoding: UTF-8
Language: en-US
LazyData: true
NeedsCompilation: no
Packaged: 2026-08-20 08:48:02 UTC; bundfuss
Author: Stefan Bundfuss [aut, cre],
  Amit Jain [aut],
  Vinh Nguyen [aut],
  Olga Starostecka [aut],
  Kiran Peddamudium [aut],
  Tomoyuki Namai [aut],
  Ross Farrugia [aut],
  Yirong Cao [ctb],
  F. Hoffmann-La Roche AG [cph, fnd],
  GlaxoSmithKline LLC [cph, fnd],
  Bristol Myers Squibb [cph, fnd]
Maintainer: Stefan Bundfuss <stefan.bundfuss@external.roche.com>
Repository: CRAN
Date/Publication: 2026-08-21 06:00:24 UTC
Built: R 4.5.2; ; 2026-08-21 10:16:44 UTC; unix
