---
title: "Get Started"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Get Started}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r setup, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)
```

# Introduction

As this is a package extension, if you are new to `{admiral}` then the best
place to first start reading would be the [Get
Started](https://pharmaverse.github.io/admiral/cran-release/articles/admiral.html)
page. This extension package follows the same main idea and conventions, and
re-uses many functions from `{admiral}`, so it is important to thoroughly
understand these to be able to use `{admiralonco}`.

# Creating Oncology ADaM Datasets

For the oncology ADaM data structures, an overview of the flow and example function calls
for the most common steps are provided by the following vignettes:

- [Creating a Basic ADRS](adrs_basic.html)
- [Creating ADRS (Including Non-standard Endpoints)](adrs.html)
- [Creating ADTTE](adtte.html)
- [Creating ADTR](adtr.html)

`{admiralonco}` also provides template R scripts as a starting point. They can be
created by calling `use_ad_template()` from `{admiral}`, e.g.,

```{r}
library(admiral)
```

```r
use_ad_template(
  adam_name = "adrs",
  save_path = "./ad_adrs.R",
  package = "admiralonco"
)
```

A list of all available templates can be obtained by `list_all_templates()`
from `{admiral}`:

```{r}
list_all_templates(package = "admiralonco")
```

# Support

Support is provided via the [admiral Slack
channel](https://pharmaverse.slack.com/).
